==> imwiki-0.6.0a.tar.gz: imwiki-0.6.0a/imLib/imMacro/RecentChanges.py <==
import time

import imLib.Logger as Logger
import imLib.utils as utils
import imLib.Request as Request
import imLib.Page as Page
import imLib.config as config

dateFormat = '%Y/%m/%d'
timeFormat = '[%I:%M %p]'
def makeDate(t):
	return int(time.mktime(list(time.localtime(float(t))[:3])+[0]*6))

def parse():
	request = Request.Request()
	lines = Logger.getEditLogRawLines()
	lines.reverse()
	logDict = {}
	L = []
	for line in lines:
		line = line.split('\t')
		categoryPath = line[1]
		pageName = line[2]
		editTime = line[3]
		pagePath = categoryPath and categoryPath+'/'+pageName or pageName
		if request.categoryPath and not pagePath.startswith(request.categoryPath+'/'):
			continue
		if pagePath not in L:
			L.append(pagePath)
			date = makeDate(editTime)
			if not logDict.has_key(date):
				logDict[date] = []
			logDict[date].append(line)
	return logDict

def run():
	logDict = parse()
	if not logDict:
		return 'No Changes' #FIXME
	dateList = logDict.keys()
	myCmp = lambda lhs, rhs: cmp(rhs, lhs)
	dateList.sort(myCmp)
	L = ['<table id="recentChanges">']	
	for date in dateList:
		L.append('<tr><td class="rcDate" colspan="3">%s</td></tr>' % time.strftime(dateFormat, time.localtime(date)))
		for logLine in logDict[date]:
			page = Page.getPage(logLine[1], logLine[2])
			pageLink = page and page.toLink() or utils.makeLink(logLine[1], logLine[2], 'notExist')
			editorPage = Page.getPage(config.homepageCategoryName, logLine[4].strip())
			editorPageLink = editorPage and editorPage.toLink(linkName=editorPage.pageName) or logLine[4]
			L.append('''<tr>
	<td class="rcPageLink">%s</td>
	<td class="rcTime">%s</td>
	<td class="rcEditor">%s</td>
</tr>''' % (pageLink, time.strftime(timeFormat, time.localtime(float(logLine[3]))), editorPageLink)) 
	L.append('</table>')
	return '\n'.join(L)

==> imwiki-0.6.2.tar.gz: imwiki-0.6.2/imLib/imMacro/RecentChanges.py <==
# -*- coding: utf8 -*-
import time

import imLib.Logger as Logger
import imLib.utils as utils
import imLib.Request as Request
import imLib.Page as Page
import imLib.config as config

dateFormat = '%Y/%m/%d'
timeFormat = '[%I:%M %p]'
def makeDate(t):
	return int(time.mktime(list(time.localtime(float(t))[:3])+[0]*6))

def parse():
	request = Request.Request()
	lines = Logger.getEditLogRawLines()
	lines.reverse()
	logDict = {}
	L = []
	for line in lines:
		line = line.split('\t')
		categoryPath = line[1]
		pageName = line[2]
		editTime = line[3]
		pagePath = categoryPath and categoryPath+'/'+pageName or pageName
		if request.categoryPath and not pagePath.startswith(request.categoryPath+'/'):
			continue
		if pagePath not in L:
			L.append(pagePath)
			date = makeDate(editTime)
			if not logDict.has_key(date):
				logDict[date] = []
			logDict[date].append(line)
	return logDict

def makeDiffLink(categoryPath, pageName): 
	page = Page.getPage(categoryPath, pageName)
	request = Request.Request()
	actionPath = request.scriptName + '/' + utils.joinPath(utils.encode(categoryPath), utils.encode(pageName))
	return '<a href="%s?action=diff"><img src="%s/img/%s.png" alt="D" /></a>' % (actionPath, config.urlPrefix, page and 'diff' or 'trashcan') 

def run():# FIXME  너무 지져분하다.
	logDict = parse()
	if not logDict:
		return 'No Changes' #FIXME
	dateList = logDict.keys()
	myCmp = lambda lhs, rhs: cmp(rhs, lhs)
	dateList.sort(myCmp)
	L = ['<table id="recentChanges">']	
	for date in dateList:
		L.append('<tr><td class="rcDate" colspan="3">%s</td></tr>' % time.strftime(dateFormat, time.localtime(date)))
		for logLine in logDict[date]:
			page = Page.getPage(logLine[1], logLine[2])
			pageLink = page and page.toLink() or utils.makeLink(logLine[1], logLine[2], 'notExist')
			diffLink = makeDiffLink(logLine[1], logLine[2])
			editorPage = Page.getPage(config.homepageCategoryName, logLine[4].strip())
			editorPageLink = editorPage and editorPage.toLink(linkName=editorPage.pageName) or logLine[4]
			L.append('''<tr>
	<td class="rcPageLink">%s %s</td>
	<td class="rcTime">%s</td>
	<td class="rcEditor">%s</td>
</tr>''' % (diffLink, pageLink, time.strftime(timeFormat, time.localtime(float(logLine[3]))), editorPageLink)) 
	L.append('</table>')
	return '\n'.join(L)
